@@ -146,7 +146,7 @@ class PdfDocument:
             self._actual_input.close()
     
     
-    def save(self, buffer, version=None):
+    def save(self, buffer, version=None, rm_security=False):
         """
         Save the document into an output buffer, at its current state.
         
@@ -157,6 +157,9 @@ class PdfDocument:
             version (typing.Optional[int]):
                  The PDF version to use, given as an integer (14 for 1.4, 15 for 1.5, ...).
                  If :data:`None`, PDFium will set a version automatically.
+            rm_security (bool):
+                If this option is :data:`True` and an encrypted PDF is saved, its password protection will be removed.
+                Otherwise, encryption will be retained.
         """
         
         WriteFunctype = ctypes.CFUNCTYPE(ctypes.c_int, ctypes.POINTER(pdfium.FPDF_FILEWRITE), ctypes.POINTER(None), ctypes.c_ulong)
@@ -164,7 +167,11 @@ class PdfDocument:
         filewrite = pdfium.FPDF_FILEWRITE()
         filewrite.WriteBlock = WriteFunctype( _writer_class(buffer) )
         
-        saveargs = (self._pdf, ctypes.byref(filewrite), pdfium.FPDF_NO_INCREMENTAL)
+        flags = pdfium.FPDF_NO_INCREMENTAL
+        if rm_security:
+            flags |= pdfium.FPDF_REMOVE_SECURITY
+        
+        saveargs = (self._pdf, ctypes.byref(filewrite), flags)
         if version is None:
             success = pdfium.FPDF_SaveAsCopy(*saveargs)
         else:
@@ -362,7 +369,7 @@ class PdfDocument:
         )
         page = pdf.get_page(index)
         result = getattr(page, "render_to"+renderer_name)(**kwargs)
-        [g.close() for g in (page, pdf)]
+        for g in (page, pdf): g.close()
         return result, index
     
     
