@@ -5,4 +5,7 @@
 set -v
 
 python3 -m pip install . -v --no-build-isolation
-unlink ./setupsrc/pl_setup/.presetup_done.txt
+rm -f data/.presetup_done.txt
+pushd src/pypdfium2/
+rm -f _pypdfium.py pdfium pdfium.dll pdfium.dylib
+popd
